/******************************************************************************
 * crc.h : crc calculation routines declarations
 *
 * Collected & written by Stas Degteff <g@grumbler.org>
 * (c) Stas Degteff
 * Partially copiright (c) Husky development team
 * Algorithm is described in the ISO 3309, IEEE V.42 and another documents.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; see the file COPYING.  If not, write
 * to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA
 *
 * See also http://www.gnu.org
 *****************************************************************************
 * $Id: crc.h,v 1.2 2004/04/18 19:22:56 stas_degteff Exp $
 */

#ifndef _CRC_H
#define _CRC_H


#ifndef UINT32
 #define UINT32 unsigned int
#endif

/* CRC32 initial value */
#define CRC32INIT ((UINT32)0xFFFFFFFFUL)

/* Define read() buffer */
#define CRC_BUFFER_SIZE 80000

/* CRC32 table for polinom 0xedb88320 */
extern UINT32 crc32tab[256];

/* Calculate CRC32 of one byte. Start value is 0xFFFFFFFF (or (UINT32)-1L)
   After calculation of all yuo should be: crc =^ 0xFFFFFFFF.
 */
#define bytecrc32(byte,crc) \
        ( crc32tab[((UINT32)crc ^ (byte)) & 0xff] ^ ((UINT32)crc >> 8) )


/* Calculate CRC32 for memory array
   str: array
   size: array size
   initcrc: initial value (start from 0xFFFFFFFFUL)
   After calculation of all yuo should be: crc =^ 0xFFFFFFFF.
 */
UINT32 memcrc32(const char *str, int size, UINT32 initcrc);

/* Calculate CRC32 for ASCIIZ string
   str: string
   initcrc: initial value (start from 0xFFFFFFFFUL)
   After calculation of all yuo should be: crc =^ 0xFFFFFFFF.
 */
UINT32 strcrc32(const char *str, UINT32 initcrc);

/* Calculate CRC32 for file
   filename: file name for calculate CRC32
 */
UINT32 filecrc32(const char *filename);


#endif
